==> scilab_5.5.2.orig.tar.gz: scilab-5.5.2/modules/console/src/c/promptecho.c <==
/*
* Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
* Copyright (C) DIGITEO - 2009 - Allan CORNET
*
* This file must be used under the terms of the CeCILL.
* This source file is licensed as described in the file COPYING, which
* you should have received as part of this distribution.  The terms
* are also available at
* http://www.cecill.info/licences/Licence_CeCILL_V2.1-en.txt
*
*/
/*--------------------------------------------------------------------------*/
#include <stdio.h>
#include <string.h>
#include "promptecho.h"
#include "basout.h"
#include "MALLOC.h"
#include "prompt.h"
#ifdef _MSC_VER
#include "strdup_Windows.h"
#endif
/*--------------------------------------------------------------------------*/
int C2F(promptecho)(int *lunit, char *string, int *strl, int string_len)
{
    char *promptstr = NULL;
    char *buffstr =  NULL;
    int lenbuffstr = 0;

    if (GetTemporaryPrompt())
    {
        promptstr = strdup(GetTemporaryPrompt());
    }
    else
    {
        promptstr = (char*)MALLOC(sizeof(char) * (PROMPT_SIZE_MAX + 1));
        GetCurrentPrompt(promptstr);
    }

    /* concates prompt with input command line */
    if (promptstr)
    {
        lenbuffstr = (int) ( strlen(string) + strlen(promptstr) );
        buffstr = (char*) MALLOC(sizeof(char) * (lenbuffstr + 1));
        if (buffstr)
        {
            strcpy(buffstr, promptstr);
            strcat(buffstr, string);
        }
        FREE(promptstr);
        promptstr = NULL;
    }

    /* displays command line with prompt */
    if (buffstr)
    {
        int io = 0;
        C2F(basout)(&io, lunit, buffstr, lenbuffstr);
        FREE(buffstr);
        buffstr = NULL;
    }
    return 0;
}
/*--------------------------------------------------------------------------*/

==> scilab_6.0.0.orig.tar.gz: scilab-6.0.0/modules/console/src/c/promptecho.c <==
/*
* Scilab ( http://www.scilab.org/ ) - This file is part of Scilab
* Copyright (C) DIGITEO - 2009 - Allan CORNET
*
 * Copyright (C) 2012 - 2016 - Scilab Enterprises
 *
 * This file is hereby licensed under the terms of the GNU GPL v2.0,
 * pursuant to article 5.3.4 of the CeCILL v.2.1.
 * This file was originally licensed under the terms of the CeCILL v2.1,
 * and continues to be available under such terms.
 * For more information, see the COPYING file which you should have received
 * along with this program.
*
*/
/*--------------------------------------------------------------------------*/
#include <stdio.h>
#include <string.h>
#include "promptecho.h"
#include "basout.h"
#include "sci_malloc.h"
#include "prompt.h"
#include "os_string.h"
/*--------------------------------------------------------------------------*/
int C2F(promptecho)(int *lunit, char *string, int *strl, int string_len)
{
    char *promptstr = NULL;
    char *buffstr =  NULL;
    int lenbuffstr = 0;

    if (GetTemporaryPrompt())
    {
        promptstr = os_strdup(GetTemporaryPrompt());
    }
    else
    {
        promptstr = (char*)MALLOC(sizeof(char) * (PROMPT_SIZE_MAX + 1));
        GetCurrentPrompt(promptstr);
    }

    /* concates prompt with input command line */
    if (promptstr)
    {
        lenbuffstr = (int) ( strlen(string) + strlen(promptstr) );
        buffstr = (char*) MALLOC(sizeof(char) * (lenbuffstr + 1));
        if (buffstr)
        {
            strcpy(buffstr, promptstr);
            strcat(buffstr, string);
        }
        FREE(promptstr);
        promptstr = NULL;
    }

    /* displays command line with prompt */
    if (buffstr)
    {
        int io = 0;
        C2F(basout)(&io, lunit, buffstr, lenbuffstr);
        FREE(buffstr);
        buffstr = NULL;
    }
    return 0;
}
/*--------------------------------------------------------------------------*/
